#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 logging-facade
version:              0.3.1
visibility:           public
id:                   logging-facade-0.3.1-SoeJesYB8F3GIG7L7uCQ1
key:                  logging-facade-0.3.1-SoeJesYB8F3GIG7L7uCQ1
license:              MIT
copyright:            (c) 2014-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  cb50d9f0e26128d7503985fec2d62f99
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.6.6/site-local/logging-facade-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/logging-facade-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/logging-facade-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logging-facade
hs-libraries:         HSlogging-facade-0.3.1-SoeJesYB8F3GIG7L7uCQ1
depends:
    base-4.18.2.1 call-stack-0.4.0-kGqKakyWMGKxttCQRWPoN
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

